API Reference
=============

.. automodule:: epubaker

.. autoclass:: Epub3
    :members:
    :inherited-members:

.. autoclass:: Epub2
    :members:
    :inherited-members:

.. autoclass:: File
    :members:

.. autoclass:: Section
    :members:

.. autoclass:: Joint
    :members:


.. toctree::
    metas
    tools
    xl
